<?php

namespace App\Http\Controllers;

use App\Traits\AuthTrait;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;

class AuthController extends Controller
{
    private $client;
    public function __construct()
    {
        $this->middleware('custom-guest')->except('logout');
        $root_url = getenv("WHEATBAKER_API_URL");
        $this->client = new Client([
            'base_uri'=>$root_url,
            'headers'=>['Accept' => 'application/json',
                'Content-Type'=>'application/json',
            ]
        ]);
    }
    use AuthTrait;
    public function login()
    {
        return view('auth.login');
    }

    public function postLogin(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'email'=>'required|email',
            'password'=>'required'
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>"Invalid email address or password."
            ]);
        }
        $ping_response = $this->pingServer();
        if($ping_response->status_code==200)
        {
           $login_response = $this->userLogin((object)$request->all());
           if($login_response->status_code==200)
           {
               if($login_response->response->status == 0)
               {
                   return response()->json($login_response->response);
               }
               Cookie::queue('api_token',$login_response->response->success->token,60);
               Cookie::queue('user',json_encode($login_response->response->success->user),60);
               $intended_url= Redirect::intended()->getTargetUrl();
               return response()->json(['status'=>1,'message'=>'You have successfully logged in',
                   "url"=>$intended_url
               ]);
           }
           return response()->json($login_response);
        }
        return response()->json((object)[
            'status'=>0,
            'message'=>"An error occurred on the server,please try again."
        ]);
    }

    public function logout(Request $request)
    {
        Cookie::queue(Cookie::forget('api_token'));
        Cookie::queue(Cookie::forget('user'));
        return redirect()->route('login');
    }
}
