<?php

namespace App\Http\Controllers;

use App\Traits\PasswordTrait;
use App\Traits\UtilityTrait;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;

class PasswordController extends Controller
{

    use UtilityTrait,PasswordTrait;
    public function __construct()
    {
        $root_url = getenv("WHEATBAKER_API_URL");
        $this->client = new Client([
            'base_uri'=>$root_url,
            'headers'=>['Accept' => 'application/json',
                'Content-Type'=>'application/json',
            ]
        ]);
    }

    public function resetPassword()
    {
        return view("auth.passwords.request_reset");
    }

    public function sendPasswordRequest(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'email'=>'required|email'
        ]);

        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Invalid email address.'
            ]);
        }
            $callback_url = route("password.reset");
            $sendLink_response = $this->userRequestLink($request->email,$callback_url);
            if($sendLink_response->status_code==200)
           {
               if($sendLink_response->response->status == 1)
               {
                   return response()->json($sendLink_response->response);
               }
            
           }
           return response()->json($sendLink_response);
    }

    public function resetOldPassword(Request $request)
    {
        
        $validator = Validator::make($request->all(),[
            'token'=>'required'
        ]);

       if($validator->fails())
        {
            return redirect()->route("reset")->withError("Invalid token for password reset");
        }

        $token = $request->token;
        $verify_response = $this->verifyUserToken($token);
        if($verify_response->status_code==200)
        {
            if($verify_response->response->status == 1)
            {
                return view('auth.passwords.reset_password')
                        ->with(['response'=>$verify_response->response]);
            }
         
        }
        return redirect()->route("reset")->withError("Could not verify the token");
    }

    public function sendPasswordReset(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'token'=>'required',
            'email'=>'required',
            'password'=>'required',
            'password_confirmation'=>'required'
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Invalid password fields.'
            ]);
        }

        $validator = Validator::make($request->all(),[
            'password'=>'confirmed'
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Passwords do not match.'
            ]);
        }
        $change_response = $this->updatePassword((object)$request->all());
        if($change_response->status_code==200)
        {
            
          return response()->json($change_response->response);
        }
        return response()->json($change_response);
    }

    public function changePassword(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'current_password'=>'required',
            'password'=>'required',
            'password_confirmation'=>'required'
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Invalid password fields.'
            ]);
        }

        $validator = Validator::make($request->all(),[
            'password'=>'confirmed'
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Passwords do not match.'
            ]);
        }
       $change_response = $this->changeUserPassword((object)$request->all());
       if($change_response->status_code==200)
        {
          return response()->json($change_response->response);
        }
        return response()->json($change_response);
    }

}
