<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Traits\AccountTrait;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Input;

class AccountController extends Controller
{
    use AccountTrait;
    public function __construct()
    {
        $this->middleware('custom-auth');
        $root_url = getenv("WHEATBAKER_API_URL");
        $this->client = new Client([
            'base_uri'=>$root_url,
            'headers'=>['Accept' => 'application/json',
                'Content-Type'=>'application/json',
            ]
        ]);
    }

    public function notifications(Request $request)
    {
        $read = $request->input('read');
        $page = $request->input('page');
        $notification_response = $this->userNotifications($read,$page);
        if($notification_response->status_code==200)
        {
           
            return view('user.notifications')
                ->with(['response'=>$notification_response->response]);
        }else if($notification_response->status_code==401)
        {

            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return redirect()->route("login")
                ->withMessage('Token has expired, please login again.');
        }
       
        return abort(403);
    }

    public function moreNotifications(Request $request)
    {
        $read = $request->input('read');
        $page = $request->input('page');
        $notification_response = $this->userNotifications($read,$page);
        if($notification_response->status_code==200)
        {
            return response()->json($notification_response->response);
        }
       
        return response()->json($notification_response);
    }

    public function deleteNotification(Request $request)
    {
        $notification_id = $request->notification_id;
        $delete_response = $this->deleteUserNotification($notification_id);
        if($delete_response->status_code==200)
        {
            return response()->json($delete_response->response);
        }else if($delete_response->status_code==401)
        {
            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return redirect()->route("login")
                ->withMessage('Token has expired, please login again.');
        }

        return response()->json((object)[
            'status'=>0,
            "message"=>'An unknown error occurred'
        ]);

    }

    public function makeNotificationAsRead(Request $request)
    {
        $notification_id = $request->notification_id;
        $delete_response = $this->makeUserNotification($notification_id);
        if($delete_response->status_code==200)
        {
            return response()->json($delete_response->response);
        }else if($delete_response->status_code==401)
        {
            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return redirect()->route("login")
                ->withMessage('Token has expired, please login again.');
        }

        return response()->json((object)[
            'status'=>0,
            "message"=>'An unknown error occurred'
        ]);

    }

    public function userStatement()
    {
        $transactions = [];
        return  view('user.statement',compact('transactions'));
    }

    public function getStatement(Request $request)
    {
        $request->validate([
            'from_date'=>'required|date',
            'to_date'=>'required|date'
        ]);
        $statement_response = $this->getUserStatement((object)$request->all());
        if($statement_response->status_code==200)
        {
            return view('user.statement')
                ->with(['transactions'=>$statement_response->response]);
        }else if($statement_response->status_code==401)
        {

            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return redirect()->route("login")
                ->withMessage('Token has expired, please login again.');
        }
        return abort(403);
    }
}
