<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Traits\ProfileTrait;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class UserController extends Controller
{
    use ProfileTrait;

    public function __construct()
    {
        $this->middleware('custom-auth');
        $root_url = getenv("WHEATBAKER_API_URL");
        $this->client = new Client([
            'base_uri'=>$root_url,
            'headers'=>['Accept' => 'application/json',
                'Content-Type'=>'application/json',
            ]
        ]);
    }

    public function profile()
    {
        $profile_response = $this->userProfile();
        if($profile_response->status_code==200)
        {
            $data = $profile_response->response;
            return view("user.profile")
                ->with(['profile'=>$data->profile,'states'=>$data->states,'cities'=>$data->cities]);

        }else if($profile_response->status_code==401)
        {

            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return redirect()->route("login")
                ->withMessage('Token has expired, please login again.');
        }
        return abort(403);
    }

    public function updateProfile(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'first_name'=>'required',
            'last_name'=>'required',
            'address'=>'required',
            'phone_no'=>'required',
            'state_id'=>'required',
            'city_id'=>'required',
            'country_id'=>'required',
        ]);
        if($validator->fails())
        {
            return response()->json((object)[
                'status'=>0,
                'message'=>'Please fill all the required fields'
            ]);
        }
        $profile_response = $this->updateUserProfile((object)$request->all());
        if($profile_response->status_code==200)
        {
            return response()->json($profile_response->response);
        }else if($profile_response->status_code==401)
        {
            Cookie::queue(Cookie::forget('api_token'));
            Cookie::queue(Cookie::forget('user'));
            return response()->json((object)[
                'status'=>0,
                'code'=>401,
                'message'=>'Token has expired please login again'
            ]);
        }
        return response()->json((object)[
            'status'=>0,
            'message'=>'An unknown error occurred'
        ]);
    }
}
