<?php


namespace App\Traits;


use GuzzleHttp\Exception\ClientException;
use Illuminate\Support\Facades\Cookie;

trait PasswordTrait
{
    use ErrorTrait;

    public function userRequestLink($email,$url)
    {
        $slug=getenv("PROGRAM_SLUG");
        try{
            $result = $this->client->post($slug.'/request_reset', [
                'json'=>[
                    'password_callbackurl'=>$url,
                    'email'=>$email
                ]
            ]);
            $response = json_decode($result->getBody()->getContents());
            return ((object)[
                'status_code'=>200,
                "response"=>$response
            ]);
        }catch (ClientException $ex)
        {
            return $this->formulateErrorResponse($ex);
        }

    }


    public function verifyUserToken($token)
    {
        $slug=getenv("PROGRAM_SLUG");
        try{
            $result = $this->client->post($slug.'/verify_token', [
                'json'=>[
                    'token'=>$token,
                ]
            ]);
            $response = json_decode($result->getBody()->getContents());
            return ((object)[
                'status_code'=>200,
                "response"=>$response
            ]);
        }catch (ClientException $ex)
        {
            return $this->formulateErrorResponse($ex);
        }

    }

    public function updatePassword($password_object)
    {
        $slug=getenv("PROGRAM_SLUG");
        try{
            $result = $this->client->post($slug.'/reset_password', [
                'json'=>[
                    'token'=>$password_object->token,
                    'email'=>$password_object->email,
                    'password'=>$password_object->password
                ]
            ]);
            $response = json_decode($result->getBody()->getContents());
            return ((object)[
                'status_code'=>200,
                "response"=>$response
            ]);
        }catch (ClientException $ex)
        {
            return $this->formulateErrorResponse($ex);
        }

    }


    public function changeUserPassword($password_object)
    {

        try{
            $result = $this->client->post('change_password', [
                'json'=>[
                    'current_password'=>$password_object->current_password,
                    'new_password'=>$password_object->password,
                ],
                'headers'=>[ 'Authorization' => 'Bearer ' . Cookie::get("api_token")]
            ]);

            $response = json_decode($result->getBody()->getContents());
            return ((object)[
                'status_code'=>200,
                "response"=>$response
            ]);
        }catch (ClientException $ex)
        {
            return $this->formulateErrorResponse($ex);
        }

    }

    
}
